Module config

Contains the Config structures for the generate method.

Re-exports

pub use crate::generator::BoxFlags;
pub use crate::generator::GeneratorFlags;
pub use crate::generator::SerdeSupport;
pub use crate::generator::TypedefMode;
pub use crate::schema::Namespace;
pub use crate::schema::NamespacePrefix;
pub use crate::types::IdentType;
pub use crate::types::Type;

Structs

Config
Configuration structure for the generate method.
GeneratorConfig
Configuration for the code generator.
IdentTriple
Identifier that is used inside the config.
InterpreterConfig
Configuration for the schema interpreter.
InterpreterFlags
Flags to control the Interpreter.
OptimizerConfig
Configuration for the type information optimizer.
OptimizerFlags
Flags to control the Optimizer.
ParserConfig
Configuration for the schema parser.
ParserFlags
Flags to control the Parser.
TypePostfix
Postfixed that will be added to the different types generated by the code generator.

Enums

Generate
Configuration which types the Generator should generate code for used in GeneratorConfig.
NamespaceIdent
Identifies a namespace by either it’s known prefix or by the namespace directly.
Renderer
Configuration for the Renderers the Generator should use for rendering the code.
Resolver
Configuration for the Resolvers used in ParserConfig.
Schema
Configuration for the schemas to load used in ParserConfig.