pub enum NamespaceIdent {
Anonymous,
Id(NamespaceId),
Prefix(NamespacePrefix),
Namespace(Namespace),
}Expand description
Identifies a namespace by either it’s id, it’s known prefix or it’s namespace.
Used in IdentQuadruple.
Variants
Anonymous
Identifies the anonymous namespace.
Id(NamespaceId)
Use the actual id the namespace is identified with.
Prefix(NamespacePrefix)
Uses a namespace prefix to refer to a specific namespace in the schema.
Namespace(Namespace)
Uses the full namespace to refer to a specific namespace in the schema.
Implementations
Sourceimpl NamespaceIdent
impl NamespaceIdent
Sourcepub fn id(value: NamespaceId) -> Self
pub fn id(value: NamespaceId) -> Self
Creates a new NamespaceIdent::Id instance from the passed value.
Sourcepub fn prefix<X>(value: X) -> Selfwhere
NamespacePrefix: From<X>,
pub fn prefix<X>(value: X) -> Selfwhere
NamespacePrefix: From<X>,
Creates a new NamespaceIdent::Prefix instance from the passed value.
Sourcepub fn namespace<X>(value: X) -> Self
pub fn namespace<X>(value: X) -> Self
Creates a new NamespaceIdent::Namespace instance from the passed value.