RenderStep

Enum RenderStep 

pub enum RenderStep {
    Types,
    TypesSerdeXmlRs {
        version: SerdeXmlRsVersion,
    },
    TypesSerdeQuickXml,
    Defaults,
    NamespaceConstants,
    EnumConstants,
    PrefixConstants,
    WithNamespaceTrait,
    QuickXmlSerialize {
        namespaces: NamespaceSerialization,
        default_namespace: Option<Namespace>,
    },
    QuickXmlDeserialize {
        boxed_deserializer: bool,
    },
}
Configuration for the RenderStepss the Renderer should use for rendering the code.

*Caution* Some render steps are incompatible to each other (e.g. only one `TypesXXX` step should be used, because they render the general type structure). While other render steps depend on each other (e.g. `QuickXmlXXX` depends on `Types` and `NamespaceConstants`).

Variants



Types

Step to render the pure types.



TypesSerdeXmlRs

Step to render the types with serde-xml-rs support.

Fields

version: SerdeXmlRsVersion

Version of serde-xml-rs to render the code for.



TypesSerdeQuickXml

Step to render the types with quick_xml serde support.



Defaults

Renderer to render associated methods that return the default values of the different fields of a struct.



NamespaceConstants

Renderer to add constants for the namespaces to the generated code.



EnumConstants

Renderer to add constants for each variant of an enumeration using its simple base type.



PrefixConstants

Renderer to add constants for the namespace prefixes to the generated code.



WithNamespaceTrait

Renderer that adds the WithNamespace trait to the generated types.



QuickXmlSerialize

Renderer that renders code for the quick_xml serializer of the different types.

Fields

namespaces: NamespaceSerialization

Whether to add namespaces to the root element during serialization or not.

default_namespace: Option<Namespace>

Default namespace to use for the serialization.



QuickXmlDeserialize

Renderer that renders code for the quick_xml deserializer of the different types.

Fields

boxed_deserializer: bool

Whether to box the deserializer or not.

For more details have a look at QuickXmlDeserializeRenderer::boxed_deserializer.

Implementations

Source

impl RenderStep

pub fn is_same(&self, other: &Self) -> bool

Return true if the passed value identifies the same step, false otherwise.