RenderStepConfig

Trait RenderStepConfig 

pub trait RenderStepConfig: Debug + Any {
    // Required methods
    fn boxed_clone(&self) -> Box<dyn RenderStepConfig>;
    fn into_render_step(self: Box<Self>) -> Box<dyn RenderStepTrait>;

    // Provided methods
    fn render_step_type(&self) -> RenderStepType { ... }
    fn is_mutual_exclusive_to(&self, other: &dyn RenderStepConfig) -> bool { ... }
}
Helper trait to deal with custom render steps.

Required Methods

fn boxed_clone(&self) -> Box<dyn RenderStepConfig>

Returns a boxed clone of the current object.

fn into_render_step(self: Box<Self>) -> Box<dyn RenderStepTrait>

Creates the actual render step and returned it as a box.

Provided Methods

fn render_step_type(&self) -> RenderStepType

Returns the type of this render step.

fn is_mutual_exclusive_to(&self, other: &dyn RenderStepConfig) -> bool

Returns true if self is mutual exclusive to other, false otherwise.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors