pub fn exec_interpreter_with_ident_cache(
config: InterpreterConfig,
schemas: &Schemas,
) -> Result<(MetaTypes, IdentCache), Error>Expand description
Executes the Interpreter with the passed config and schema.
Returns the interpreted MetaTypes structure, as well as the IdentCache
that can be used to lookup TypeIdentifiers.
Errors
Returns a suitable Error type if the process was not successful.