Module renderer

The renderer module contains different types that implements the Renderer trait.

Structs

DefaultsRenderer
Implements a Renderer that renders associated methods that return the default values of the different attributes and elements according to the schema.
NamespaceConstantsRenderer
Implements a Renderer that renders constants for the different namespaces used in the schema.
QuickXmlDeserializeRenderer
Implements a Renderer that renders the code for the quick_xml deserialization.
QuickXmlSerializeRenderer
Implements a Renderer that renders the code for the quick_xml serialization.
TypesRenderer
Implements a Renderer that renders the actual rust types of the types defined in the schema.
WithNamespaceTraitRenderer
Implements a Renderer that renders the WithNamespace trait for each type defined in the schema.

Traits

Renderer
Trait that is used to define a renderer.