Module misc

Module misc 

Module for miscellaneous utilities and helpers.

This module provides various utility functions and types that support the XSD parser.

Functions

qname_default
Generates a default value or constant for the QName type from the passed value and returns it as a TokenStream.