pub fn qname_default(
ctx: &Context<'_, '_>,
value: &str,
mode: ValueGeneratorMode,
) -> Result<ValueRendererBox, Error>Expand description
Generates a default value or constant for the QName type
from the passed value and returns it as a TokenStream.