pub enum EnumerationVariantValue {
None,
ByteLiteral(Ident, ValueRendererBox),
Constant(Ident, ValueRendererBox),
}Expand description
Value renderer to render either a constant or a getter function for the value of this variant represented at its simple base type.
Variants
None
No value renderer, because the simple base type of this enumeration is not supported.
ByteLiteral(Ident, ValueRendererBox)
Value renderer to render a byte string literal for the value of this variant.
Constant(Ident, ValueRendererBox)
Value renderer to render a constant for the value of this variant.