pub struct ConstrainsData<'types> {
pub meta: Cow<'types, Constrains>,
pub range: Range<Bound<ValueRendererBox>>,
}Expand description
Code generator data for the constrains of a specific type.
Fields
meta: Cow<'types, Constrains>Reference to the original constrains information.
range: Range<Bound<ValueRendererBox>>The the value should ne in as token stream literals.