pub struct EnumerationData<'types> {
pub meta: Cow<'types, EnumerationMeta>,
pub constrains: ConstrainsData<'types>,
pub type_ident: Ident,
pub variants: Vec<EnumerationDataVariant<'types>>,
pub trait_impls: Vec<TokenStream>,
pub simple_base_type: Option<PathData>,
}Expand description
Contains additional information for the rendering process of a
MetaTypeVariant::Enumeration
type.
Fields
meta: Cow<'types, EnumerationMeta>Reference to the original type information.
constrains: ConstrainsData<'types>Code generator data for the constrains of the type.
type_ident: IdentThe identifier of the rendered type.
variants: Vec<EnumerationDataVariant<'types>>List of variants of this enumeration.
trait_impls: Vec<TokenStream>List of traits that needs to be implemented by this type.
simple_base_type: Option<PathData>Simple base type of this enumeration.