pub struct EnumerationDataVariant<'types> {
pub meta: Cow<'types, EnumerationMetaVariant>,
pub s_name: String,
pub b_name: Literal,
pub value: EnumerationVariantValue,
pub variant_ident: Ident,
pub target_type: Option<PathData>,
pub extra_attributes: Vec<TokenStream>,
}Expand description
Represents a enumeration variant used by EnumerationData.
Fields
meta: Cow<'types, EnumerationMetaVariant>Reference to the original type information.
s_name: StringName of the attribute as string.
b_name: LiteralName of the attribute as byte string literal.
value: EnumerationVariantValueValue renderer to render either a constant or a getter function for the value of this variant represented at its simple base type.
variant_ident: IdentName of this variant.
target_type: Option<PathData>Target type of this variant.
extra_attributes: Vec<TokenStream>Additional attributes that will be added to the variant.