Module meta

Module meta 

The meta module contains all MetaType related definitions and structures.

This module represents the internal type system used after schema interpretation, serving as an intermediate form between raw XML schema and Rust code generation. It is produced by the Interpreter and optionally optimized by the Optimizer.

Structs

AnyAttributeMeta
Contains information about attributes that may occur in the XML file that are not explicitly defined by the schema.
AnyMeta
Contains information about elements that may occur in the XML file that are not explicitly defined by the schema.
AttributeMeta
Type information that contains data about attribute definitions.
AttributesMeta
Type information that represents a list of AttributeMeta instances.
ComplexMeta
Type information that contains data about a complex type.
Constrains
Constrains defined by the different facets of a type.
CustomMeta
Type information for a custom defined type.
DerivedTypeMeta
Meta^ information about a derived type.
DynamicMeta
Type information that contains data about dynamic types.
ElementMeta
Type information that contains data about a element.
ElementsMeta
Type information that represents a list of ElementMeta instances.
EnumerationMeta
Type information that defines an enumeration type.
EnumerationMetaVariant
Type information that defines variants of an EnumerationMeta.
EnumerationMetaVariants
Type information that represents a list of EnumerationMetaVariant instances.
GroupMeta
Represents a group of elements.
MetaType
Represents a fully interpreted type from an XML schema.
MetaTypes
Intermediate representation of all resolved type and module metadata.
ModuleMeta
Represents a module used by type information in the MetaTypes structure.
ReferenceMeta
Type information that defines a reference to another type.
SchemaMeta
Represents a schema used by type information in the MetaTypes structure.
SimpleMeta
Type information that contains data about a simple type including it’s potential restrictions.
UnionMeta
Type information that defines a union type.
UnionMetaType
Type information that represents one type unified by a UnionMeta.
UnionMetaTypes
Type information that represents a list of UnionMetaType instances.

Enums

AttributeMetaVariant
Variant of a AttributeMeta
Base
Describes the base type information of a specific type information.
BuildInMeta
Union that defined the build in types of the rust language or custom defined types.
CustomMetaNamespace
Namespace information for a custom defined type.
ElementMetaVariant
Variant of a ElementMeta
ElementMode
Defines the type of an ElementMeta
MetaTypeVariant
Actual data variant a MetaType represents.
WhiteSpace
Defines how to deal with whitespaces inside a XML element.

Traits

TypeEq
Trait to check if two types are equal to each other or not.