CustomMeta

Struct CustomMeta 

pub struct CustomMeta {
    pub name: String,
    pub include: Option<String>,
    pub default: Option<ValueGeneratorBox>,
    pub namespaces: Vec<CustomMetaNamespace>,
    pub allow_any: bool,
}
Type information for a custom defined type.

Fields

name: String

Name of the custom defined type.

include: Option<String>

The path the type should be included from.

The path should be absolute, or relative to the root of the generated code.

default: Option<ValueGeneratorBox>

The handler for the default values for this custom defined type.

This is used to translate default values specified in the XSD schema, to suitable rust code.

namespaces: Vec<CustomMetaNamespace>

The namespaces needed by this custom type.

allow_any: bool

Wether this custom type contains xs:any elements or not.

Implementations

Source

impl CustomMeta

pub fn new<X>(name: X) -> Self
where X: Into<String>,

Create a new custom type information with the passed name.

pub fn name(&self) -> &str

Get the name of the custom defined type.

pub fn include(&self) -> Option<&str>

Get the include path of the custom defined type.

pub fn include_from<X>(self, include: X) -> Self
where X: Into<String>,

The the path the type should be included from.

The path should be absolute, or relative to the root of the generated code.

pub fn with_default<X: ValueGenerator>(self, x: X) -> Self

Set the handler for the default values for this custom defined type.

pub fn with_namespace<N>(self, ns: N) -> Self

Add a namespace that is needed by this custom type.

The namespace may be added to the root element during serialization.

pub fn namespaces(&self) -> &[CustomMetaNamespace]

Returns the namespaces needed by this custom type.

pub fn allow_any(&self) -> bool

Returns true if this type contains xs:any elements, false otherwise.

pub fn with_allow_any(self, value: bool) -> Self

Set wether this custom type containsxs:any elements or not.