pub enum Dependency<T> {
Include(T),
Import(T),
Override(T),
Redefine(T),
}Expand description
Represents the different types of dependencies a schema can have on another schema.
Variants
Include(T)
The schema is included by another schema.
Import(T)
The schema is imported by another schema.
Override(T)
The schema is overridden by another schema.
Redefine(T)
The schema is redefined by another schema.
Implementations
Sourceimpl<T> Dependency<T>
impl<T> Dependency<T>
Sourcepub fn map<F, U>(self, f: F) -> Dependency<U>where
F: FnOnce(T) -> U,
pub fn map<F, U>(self, f: F) -> Dependency<U>where
F: FnOnce(T) -> U,
Maps the inner value of this dependency to another type using the provided function f.