QName

Struct QName 

pub struct QName { /* private fields */ }
Type that represents a a resolved QName.

The namespace of this QName was resolved during deserialization.

Implementations

Source

impl QName

pub const fn new_const( raw: &'static [u8], index: Option<usize>, ns: Option<Namespace>, ) -> QName

Create a new QName instance from the passed raw data, index and ns.

Caution! This is a const function and can be used during compile time, but the raw data must be valid UTF-8 and the index must be correct, otherwise the QName is not valid.

pub fn from_bytes<X>(bytes: X) -> QName
where X: Into<Cow<'static, [u8]>>,

Create a new QName instance from the passed bytes.

pub fn from_helper(helper: &DeserializeHelper, raw: &[u8]) -> QName

Create a new QName instance from the passed reader and raw data.

pub fn as_bytes(&self) -> &[u8]

Get the raw bytes of the QName.

pub fn with_namespace(self, ns: Namespace) -> QName

Set the namespace of the QName to ns.

pub fn namespace(&self) -> Option<&Namespace>

Get the namespace of the QName.

pub fn take_namespace(&mut self) -> Option<Namespace>

Take the namespace of the QName, leaving None in its place.

pub fn prefix(&self) -> Option<&[u8]>

Get the prefix of the QName.

pub fn index(&self) -> Option<usize>

Get the index of the QName.

pub fn local_name(&self) -> &[u8]

Get the local name of the QName.