pub struct TypeIdent {
pub ns: NamespaceId,
pub schema: SchemaId,
pub name: Name,
pub type_: TypeIdentType,
}Expand description
Type that is used to identify types in the schema definition.
Fields
ns: NamespaceIdNamespace the type is defined in
schema: SchemaIdId of the schema file the type pointed to by this identifier was defined at.
This is needed to support the case when identifier are duplicated across
schema files, or redefined by xs:redefine or xs:override.
name: NameName of the type.
type_: TypeIdentTypeType of the identifier (because pure names are not unique in XSD).
Implementations
Sourceimpl TypeIdent
impl TypeIdent
pub const UNKNOWN: Self
pub const U8: Self
pub const U16: Self
pub const U32: Self
pub const U64: Self
pub const U128: Self
pub const USIZE: Self
pub const I8: Self
pub const I16: Self
pub const I32: Self
pub const I64: Self
pub const I128: Self
pub const ISIZE: Self
pub const F32: Self
pub const F64: Self
pub const BOOL: Self
pub const STR: Self
pub const STRING: Self
pub const ANY_TYPE: Self
pub const BUILD_IN: &[Self]
Sourceimpl TypeIdent
impl TypeIdent
Sourcepub const fn new(name: Name) -> Self
pub const fn new(name: Name) -> Self
Create a new TypeIdent instance with IdentType::Type and the passed name.
Sourcepub const fn type_(name: &'static str) -> Self
pub const fn type_(name: &'static str) -> Self
Create a new TypeIdent instance with IdentType::Type and the passed name.
Sourcepub const fn build_in(name: &'static str) -> Self
pub const fn build_in(name: &'static str) -> Self
Create a new TypeIdent instance with IdentType::BuildIn and the passed name.
Sourcepub const fn element(name: &'static str) -> Self
pub const fn element(name: &'static str) -> Self
Create a new TypeIdent instance with IdentType::Element and the passed name.
Sourcepub fn with_ns(self, ns: NamespaceId) -> Self
pub fn with_ns(self, ns: NamespaceId) -> Self
Change the NamespaceId of this type identifier.
Sourcepub fn with_schema(self, schema: SchemaId) -> Self
pub fn with_schema(self, schema: SchemaId) -> Self
Change the SchemaId of this type identifier.
Sourcepub fn with_type(self, type_: TypeIdentType) -> Self
pub fn with_type(self, type_: TypeIdentType) -> Self
Change the TypeIdentType of this type identifier.
Sourcepub fn to_property_ident(&self) -> PropertyIdent
pub fn to_property_ident(&self) -> PropertyIdent
Convert this type identifier into a PropertyIdent by dropping the schema
and type information.
Sourcepub fn is_build_in(&self) -> bool
pub fn is_build_in(&self) -> bool
Returns true if this is build-in type of the rust language, false otherwise.
Sourcepub fn is_fully_qualified(&self) -> bool
pub fn is_fully_qualified(&self) -> bool