Ident

Type Alias Ident 

pub type Ident = TypeIdent;
👎Deprecated: Use TypeIdent instead
Convenient type to not break the public interface.

The Ident was renamed to TypeIdent.

Aliased Type

pub struct Ident {
    pub ns: NamespaceId,
    pub schema: SchemaId,
    pub name: Name,
    pub type_: IdentType,
}

Fields

ns: NamespaceId

Namespace the type is defined in

schema: SchemaId

Id of the schema file the type pointed to by this identifier was defined at.

This is needed to support the case when identifier are duplicated across schema files, or redefined by xs:redefine or xs:override.

name: Name

Name of the type.

type_: IdentType

Type of the identifier (because pure names are not unique in XSD).