Error

Enum Error 

pub enum Error {
Show 17 variants TypeAlreadyDefined(TypeIdent), AmbiguousType(TypeIdent), ExpectedSimpleType(TypeIdent), ExpectedComplexType(TypeIdent), ExpectedDynamicElement(TypeIdent), UnknownType(TypeIdent), UnknownNamespace(Namespace), UnknownNamespacePrefix(NamespacePrefix), AnonymousNamespaceIsUndefined, InvalidLocalName(RawByteStr), GroupMissingRef, AttributeGroupMissingRef, InvalidAttributeReference(Box<AttributeType>), InvalidFacet(Facet), NoType, ExpectedGroupType, CircularDependency(TypeIdent),
}
error raised by the Interpreter.

Variants



TypeAlreadyDefined(TypeIdent)

Type has already been defined.

Is raised if a new type with an already existing identifier is added to the MetaTypes structure.



AmbiguousType(TypeIdent)

Ambiguous type definition

Is raised by the interpreter if it tries to resolve a certain type identifier during interpretation of the schema, but multiple matching types were found.



ExpectedSimpleType(TypeIdent)

Expected simple type.

Expected the specified type to be simple because it is referenced in a context that requires a simple type.



ExpectedComplexType(TypeIdent)

Expected complex type.

Expected the specified type to be complex because it is referenced in a context that requires a complex type.



ExpectedDynamicElement(TypeIdent)

Expected dynamic element.

Expected the specified element to be dynamic because it is referenced as substitution group.



UnknownType(TypeIdent)

Unknown type.

Is raised if a type identifier could not been resolved to the actual type information.



UnknownNamespace(Namespace)

Unknown namespace.

Is raised if the namespace URI could not be resolved.



UnknownNamespacePrefix(NamespacePrefix)

Unknown namespace prefix.

Is raised if the namespace prefix could not be resolved.



AnonymousNamespaceIsUndefined

Anonymous namespace is undefined.

Before resolving any type that is defined in the anonymous namespace you have to add it to the Schemas by either adding a schema file that uses it (see add_schema_from_str or related add_schema_xxx methods) or by defining is manually (see with_anonymous_namespace).



InvalidLocalName(RawByteStr)

Invalid local name.

Is raised if conversion from a raw local name to a string has failed.



GroupMissingRef

Group is missing the ref attribute

Is raised if a group reference in the XML schema is missing the ref attribute.



AttributeGroupMissingRef

Attribute group is missing the ref attribute

Is raised if a attribute group reference in the XML schema is missing the ref attribute.



InvalidAttributeReference(Box<AttributeType>)

Invalid attribute reference.

The attribute specified in the schema is missing some information.



InvalidFacet(Facet)

Invalid facet.

Is raised if the content of a facet could not be interpreted correctly.



NoType

Unable to create type information.

Is raised if the interpreter was not able to generate a Type from the provided schema information.



ExpectedGroupType

The interpreter expected a group type (like xs:all, xs:choice or xs:sequence).



CircularDependency(TypeIdent)

Circular dependency.

Is raised if the interpreter detects a circular strong dependency between types during type generation.