Interpreter

Struct Interpreter 

pub struct Interpreter<'a> { /* private fields */ }
The Interpreter transforms raw parsed XML schema data into semantically meaningful Rust-compatible type metadata.

It operates on a Schemas structure produced by the Parser and produces a MetaTypes structure, which is the central format used for code generation.

This abstraction allows the intermediate schema format to be reshaped into a form suitable for deterministic and idiomatic Rust code generation.

Implementations

Source

impl<'a> Interpreter<'a>

pub fn new(schemas: &'a Schemas) -> Self

Create a new Interpreter instance using the passed schemas reference.

pub fn with_type<I, T>(self, ident: I, type_: T) -> Result<Self, Error>
where I: Into<TypeIdent> + Debug, T: Into<MetaType> + Debug,

Add a custom MetaType information for the passed identifier to the resulting MetaTypes structure.

Errors

Returns a suitable Error if the operation was not successful.

pub fn with_typedef<I, T>(self, ident: I, type_: T) -> Result<Self, Error>
where I: Into<TypeIdent> + Debug, T: Into<TypeIdent> + Debug,

Add a simple type definition to the resulting MetaTypes structure using ident as identifier for the new type and type_ as target type for the type definition.

Errors

Returns a suitable Error if the operation was not successful.

pub fn with_buildin_types(self) -> Result<Self, Error>

Adds the default build-in types to the resulting MetaTypes structure.

Errors

Returns a suitable Error if the operation was not successful.

pub fn with_default_typedefs(self) -> Result<Self, Error>

Adds the type definitions for common XML types (like xs:string or xs:int) to the resulting MetaTypes structure.

Errors

Returns a suitable Error if the operation was not successful.

pub fn with_xs_any_type(self) -> Result<Self, Error>

Adds a default type definition for xs:anyType.

Errors

Returns a suitable Error if the operation was not successful.

pub fn with_xs_any_simple_type(self) -> Result<Self, Error>

Adds a default type definition for xs:anySimpleType.

Errors

Returns a suitable Error if the operation was not successful.

pub fn with_qname_type(self) -> Result<Self, Error>

Add a type definition for xs:QName that uses the xsd_parser_types::xml::QName type.

pub fn with_qname_type_from(self, path: &str) -> Result<Self, Error>

Add a type definition for xs:QName that uses the type defined at the passed path.

pub fn with_num_big_int(self) -> Result<Self, Error>

Add type definitions for numeric XML types (like xs:int) that uses num::BigInt and num::BigUint instead of build-in integer types.

Errors

Returns a suitable Error if the operation was not successful.

pub fn with_nonzero_typedefs(self) -> Result<Self, Error>

Add type definitions for numeric XML types (like xs:positiveInteger) that uses ::core::num::NonZeroIsize and ::core::num::NonZeroUsize instead of the simple integer types.

Errors

Returns a suitable Error if the operation was not successful.

pub fn with_naming<X>(self, naming: X) -> Self
where X: Naming + 'static,

Set the Naming trait that is used to generate and format names.

This accepts any type that implements the Naming trait. If you want to use an already boxed version have a look at with_naming_boxed.

pub fn with_naming_boxed(self, naming: Box<dyn Naming>) -> Self

Set the Naming trait that is used to generate and format names.

This accepts only boxed Naming trait. For easier use you can use with_naming instead.

pub fn finish(self) -> Result<(MetaTypes, IdentCache), Error>

Finishes the interpretation of the Schemas structure and returns the MetaTypes structure with the generated type information.

Errors

Returns a suitable Error if the operation was not successful.