pub enum Error<E> {
IoError(Error),
XmlError(XmlErrorWithLocation),
UrlParseError(ParseError),
UnableToResolve(Box<ResolveRequest>),
MismatchingTargetNamespace {
location: Url,
found: Namespace,
expected: Namespace,
},
Resolver(E),
InvalidFilePath(PathBuf),
}Expand description
Represents the errors that are raised by the Parser.
Variants
IoError(Error)
An IO error occurred.
XmlError(XmlErrorWithLocation)
Error while interpreting the XML for the schema.
UrlParseError(ParseError)
Error while paring the URL.
UnableToResolve(Box<ResolveRequest>)
Unable to resolve the requested resource.
MismatchingTargetNamespace
The target namespace of the included schema does not match the target namespace of the including schema.
Fields
Resolver(E)
Error while resolving the requested resource.
InvalidFilePath(PathBuf)
Invalid file path!
Is raised if the file path could not be converted to an Url.
Implementations