pub enum NamespaceSerialization {
None,
Local,
Global,
Dynamic,
}Expand description
Defines how the QuickXmlSerializeRenderStep will serialize the different
namespaces of the elements and attributes.
Variants
None
Do not serialize any namespace definitions.
Local
All namespace definitions are added to the local element if they are not already in scope.
Global
All namespace definitions are serialized to the root element.
Dynamic
Namespace definitions are collected at runtime by traversing the value
tree via the CollectNamespaces
trait, and only the namespaces that are actually needed by the current
value are written to the root element.
This requires the QuickXmlCollectNamespacesRenderStep
to be added to the renderer pipeline as well, so that CollectNamespaces
is implemented for all generated types.
Implementations
Sourceimpl NamespaceSerialization
impl NamespaceSerialization
Sourcepub fn is_none(&self) -> bool
pub fn is_none(&self) -> bool
Returns true if this is NamespaceSerialization::None, false otherwise.
Sourcepub fn is_some(&self) -> bool
pub fn is_some(&self) -> bool
Returns true if this is NamespaceSerialization::Local,
NamespaceSerialization::Global, or NamespaceSerialization::Dynamic,
false otherwise.