GeneratorError

Type Alias GeneratorError 

pub type GeneratorError = Error;
Aliased Type

pub enum GeneratorError {
    UnknownType(TypeIdent),
    UnknownNamespace(NamespaceId),
    InvalidDefaultValue {
        ident: TypeIdent,
        value: String,
        mode: ValueGeneratorMode,
    },
    InvalidIdentifier(InvalidIdentPath),
}

Variants



UnknownType(TypeIdent)

Unknown type identifier.

Is raised if a specific identifier could not be resolved to it’s corresponding type information.



UnknownNamespace(NamespaceId)

Unknown namespace.

Is raised if a specific namespace id could not be resolved to it’s corresponding namespace information.



InvalidDefaultValue

Invalid default value.

Is raised if the default value for an attribute defined in the schema could not be converted to a suitable default code snippet.

Fields

ident: TypeIdent

The identifier of the type for which the value should be generated.

value: String

The value that should be generated.

mode: ValueGeneratorMode

The mode that determines how the value should be generated.



InvalidIdentifier(InvalidIdentPath)

Invalid identifier.

Is raised if the user passed a invalid identifier.