Function exec_generator_module
Source pub fn exec_generator_module(
config: GeneratorConfig,
schemas: &Schemas,
types: &Types,
) -> Result<Module, Error>
Executes the Generator with the passed config, schema and types to
generate a Module for further processing.
Errors
Returns a suitable Error type if the process was not successful.