pub fn exec_generator_with_ident_cache<'types>(
config: GeneratorConfig,
schemas: &Schemas,
ident_cache: Option<&IdentCache>,
types: &'types MetaTypes,
) -> Result<DataTypes<'types>, Error>Expand description
Executes the Generator with the passed config, schema, ident_cache
and types to generate a DataTypes for further processing.
The IdentCache is needed to resolve TypeIdentifiers that should be
rendered. If it is not passed, resolving the types by only using the Schemas
structure may fail.
Errors
Returns a suitable Error type if the process was not successful.