The renderer module contains different types that implements the Renderer trait.
Structs
- Defaults
Renderer - Implements a
Rendererthat renders associated methods that return the default values of the different attributes and elements according to the schema. - Namespace
Constants Renderer - Implements a
Rendererthat renders constants for the different namespaces used in the schema. - Quick
XmlDeserialize Renderer - Implements a
Rendererthat renders the code for thequick_xmldeserialization. - Quick
XmlSerialize Renderer - Implements a
Rendererthat renders the code for thequick_xmlserialization. - Types
Renderer - Implements a
Rendererthat renders the actual rust types of the types defined in the schema. - With
Namespace Trait Renderer - Implements a
Rendererthat renders theWithNamespacetrait for each type defined in the schema.
Traits
- Renderer
- Trait that is used to define a renderer.