pub fn format_ident<'a, S>(s: S) -> Stringwhere S: Into<Cow<'a, str>>,
Format the passed string s into a valid Rust identifier by adding an underscore if it starts with a numeric character or is a Rust keyword.
s