The meta module contains all MetaType related definitions and structures.
This module represents the internal type system used after schema interpretation,
serving as an intermediate form between raw XML schema and Rust code generation.
It is produced by the Interpreter and optionally
optimized by the Optimizer.
Structs
- AnyAttribute
Meta - Contains information about attributes that may occur in the XML file that are not explicitly defined by the schema.
- AnyMeta
- Contains information about elements that may occur in the XML file that are not explicitly defined by the schema.
- Attribute
Meta - Type information that contains data about attribute definitions.
- Attributes
Meta - Type information that represents a list of
AttributeMetainstances. - Complex
Meta - Type information that contains data about a complex type.
- Constrains
- Constrains defined by the different facets of a type.
- Custom
Meta - Type information for a custom defined type.
- Derived
Type Meta - Meta^ information about a derived type.
- Dynamic
Meta - Type information that contains data about dynamic types.
- Element
Meta - Type information that contains data about a element.
- Elements
Meta - Type information that represents a list of
ElementMetainstances. - Enumeration
Meta - Type information that defines an enumeration type.
- Enumeration
Meta Variant - Type information that defines variants of an
EnumerationMeta. - Enumeration
Meta Variants - Type information that represents a list of
EnumerationMetaVariantinstances. - Group
Meta - Represents a group of elements.
- Meta
Type - Represents a fully interpreted type from an XML schema.
- Meta
Types - Intermediate representation of all resolved type and module metadata.
- Module
Meta - Represents a module used by type information in the
MetaTypesstructure. - Reference
Meta - Type information that defines a reference to another type.
- Schema
Meta - Represents a schema used by type information in the
MetaTypesstructure. - Simple
Meta - Type information that contains data about a simple type including it’s potential restrictions.
- Union
Meta - Type information that defines a union type.
- Union
Meta Type - Type information that represents one type unified by a
UnionMeta. - Union
Meta Types - Type information that represents a list of
UnionMetaTypeinstances.
Enums
- Attribute
Meta Variant - Variant of a
AttributeMeta - Base
- Describes the base type information of a specific type information.
- Build
InMeta - Union that defined the build in types of the rust language or custom defined types.
- Custom
Meta Namespace - Namespace information for a custom defined type.
- Element
Meta Variant - Variant of a
ElementMeta - Element
Mode - Defines the type of an
ElementMeta - Meta
Type Variant - Actual data variant a
MetaTyperepresents. - White
Space - Defines how to deal with whitespaces inside a XML element.
Traits
- TypeEq
- Trait to check if two types are equal to each other or not.