pub struct QName { /* private fields */ }Expand description
Implementations
Sourceimpl QName
impl QName
Sourcepub const fn new_const(
raw: &'static [u8],
index: Option<usize>,
ns: Option<Namespace>,
) -> QName
pub const fn new_const( raw: &'static [u8], index: Option<usize>, ns: Option<Namespace>, ) -> QName
Create a new QName instance from the passed raw data, index and ns.
Caution! This is a const function and can be used during compile time, but
the raw data must be valid UTF-8 and the index must be correct, otherwise
the QName is not valid.
Sourcepub fn from_bytes<X>(bytes: X) -> QName
pub fn from_bytes<X>(bytes: X) -> QName
Create a new QName instance from the passed bytes.
Sourcepub fn from_helper(helper: &DeserializeHelper, raw: &[u8]) -> QName
pub fn from_helper(helper: &DeserializeHelper, raw: &[u8]) -> QName
Create a new QName instance from the passed reader and raw data.
Sourcepub fn with_namespace(self, ns: Namespace) -> QName
pub fn with_namespace(self, ns: Namespace) -> QName
Set the namespace of the QName to ns.
Sourcepub fn take_namespace(&mut self) -> Option<Namespace>
pub fn take_namespace(&mut self) -> Option<Namespace>
Take the namespace of the QName, leaving None in its place.
Sourcepub fn local_name(&self) -> &[u8] ⓘ
pub fn local_name(&self) -> &[u8] ⓘ
Get the local name of the QName.