pub struct ExplicitNaming { /* private fields */ }Expand description
A more explicit version of Naming that does not add or
remove any suffixes or prefixes from the generated name expect the one that
were configured by Generator::with_type_postfix.
This may result in repeated string inside the generated names (like
FooTypeType), but will reduce naming conflicts in most cases.
Implementations
Sourceimpl ExplicitNaming
impl ExplicitNaming
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new ExplicitNaming instance.
Sourcepub fn unify_names(self, value: bool) -> Self
pub fn unify_names(self, value: bool) -> Self
Set whether to unify names the names for all types or not.
Unifying names means that all names will be expressed as pascal case to match the naming convention for types in Rust. This may lead to naming conflicts.
Default is true.
Sourcepub fn with_element_field_postfix<S: Into<String>>(self, postfix: S) -> Self
pub fn with_element_field_postfix<S: Into<String>>(self, postfix: S) -> Self
Set the postfix to add to generated element field names.
This can be useful to avoid naming conflicts between element and attribute fields.
Sourcepub fn with_attribute_field_postfix<S: Into<String>>(self, postfix: S) -> Self
pub fn with_attribute_field_postfix<S: Into<String>>(self, postfix: S) -> Self
Set the postfix to add to generated attribute field names.
This can be useful to avoid naming conflicts between element and attribute fields.