TypeIdent

Struct TypeIdent 

pub struct TypeIdent {
    pub ns: NamespaceId,
    pub schema: SchemaId,
    pub name: Name,
    pub type_: TypeIdentType,
}
Type that is used to identify types in the schema definition.

Fields

ns: NamespaceId

Namespace the type is defined in

schema: SchemaId

Id of the schema file the type pointed to by this identifier was defined at.

This is needed to support the case when identifier are duplicated across schema files, or redefined by xs:redefine or xs:override.

name: Name

Name of the type.

type_: TypeIdentType

Type of the identifier (because pure names are not unique in XSD).

Implementations

Source

impl TypeIdent

pub const UNKNOWN: Self

pub const U8: Self

pub const U16: Self

pub const U32: Self

pub const U64: Self

pub const U128: Self

pub const USIZE: Self

pub const I8: Self

pub const I16: Self

pub const I32: Self

pub const I64: Self

pub const I128: Self

pub const ISIZE: Self

pub const F32: Self

pub const F64: Self

pub const BOOL: Self

pub const STR: Self

pub const STRING: Self

pub const ANY_TYPE: Self

pub const BUILD_IN: &[Self]

Source

impl TypeIdent

pub const fn new(name: Name) -> Self

Create a new TypeIdent instance with IdentType::Type and the passed name.

pub const fn type_(name: &'static str) -> Self

Create a new TypeIdent instance with IdentType::Type and the passed name.

pub const fn build_in(name: &'static str) -> Self

Create a new TypeIdent instance with IdentType::BuildIn and the passed name.

pub const fn element(name: &'static str) -> Self

Create a new TypeIdent instance with IdentType::Element and the passed name.

pub fn with_ns(self, ns: NamespaceId) -> Self

Change the NamespaceId of this type identifier.

pub fn with_schema(self, schema: SchemaId) -> Self

Change the SchemaId of this type identifier.

pub fn with_name(self, name: Name) -> Self

Change the Name of this type identifier.

pub fn with_type(self, type_: TypeIdentType) -> Self

Change the TypeIdentType of this type identifier.

pub fn matches(&self, other: &Self) -> bool

Returns true if the passed identifier matches the current one.

This ignores the values stored in ns and schema if they are set to UNKNOWN.

pub fn to_property_ident(&self) -> PropertyIdent

Convert this type identifier into a PropertyIdent by dropping the schema and type information.

pub fn is_build_in(&self) -> bool

Returns true if this is build-in type of the rust language, false otherwise.

pub fn is_fully_qualified(&self) -> bool

Returns true if this identifier is fully qualified, false otherwise.

The identifier is fully qualified, if neither the ns, nor the schema is set to UNKNOWN.