pub struct QuickXmlCollectNamespacesRenderStep;Expand description
Implements a RenderStep that renders the CollectNamespaces
trait for every generated type.
This is required when using NamespaceSerialization::Dynamic
so that the serializer can traverse the value tree at runtime to discover which
XML namespaces are actually needed before emitting the root start element.