ParserError

Type Alias ParserError 

pub type ParserError<E> = Error<E>;
Type alias for pipeline::parser::Error.

Aliased Type

pub enum ParserError<E> {
    IoError(Error),
    XmlError(XmlErrorWithLocation),
    UrlParseError(ParseError),
    UnableToResolve(Box<ResolveRequest>),
    MismatchingTargetNamespace {
        location: Url,
        found: Namespace,
        expected: Namespace,
    },
    Resolver(E),
    InvalidFilePath(PathBuf),
}

Variants



IoError(Error)

An IO error occurred.



XmlError(XmlErrorWithLocation)

Error while interpreting the XML for the schema.



UrlParseError(ParseError)

Error while paring the URL.



UnableToResolve(Box<ResolveRequest>)

Unable to resolve the requested resource.



MismatchingTargetNamespace

The target namespace of the included schema does not match the target namespace of the including schema.

Fields

location: Url

Location of the schema that was processed.

found: Namespace

Target namespace that was found in the included schema.

expected: Namespace

Target namespace that was expected (i.e. the target namespace of the including schema).



Resolver(E)

Error while resolving the requested resource.



InvalidFilePath(PathBuf)

Invalid file path!

Is raised if the file path could not be converted to an Url.