pub type RendererError = Error;Expand description
Type alias for pipeline::renderer::Error.
Aliased Type
pub enum RendererError {
UnknownNamespace(NamespaceId),
InvalidIdentifier(InvalidIdentPath),
}Variants
UnknownNamespace(NamespaceId)
Unknown namespace.
Is raised if a specific namespace id could not be resolved to it’s corresponding namespace information.
InvalidIdentifier(InvalidIdentPath)
Invalid identifier.
Is raised if the user passed a invalid identifier.